/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * Parameters for creating or updating a vault
 *
 * @extends models['BaseResource']
 */
class VaultPatchParameters extends models['BaseResource'] {
  /**
   * Create a VaultPatchParameters.
   * @member {object} [tags] The tags that will be assigned to the key vault.
   * @member {object} [properties] Properties of the vault
   * @member {uuid} [properties.tenantId] The Azure Active Directory tenant ID
   * that should be used for authenticating requests to the key vault.
   * @member {object} [properties.sku] SKU details
   * @member {string} [properties.sku.name] SKU name to specify whether the key
   * vault is a standard vault or a premium vault. Possible values include:
   * 'standard', 'premium'
   * @member {array} [properties.accessPolicies] An array of 0 to 16 identities
   * that have access to the key vault. All identities in the array must use
   * the same tenant ID as the key vault's tenant ID.
   * @member {boolean} [properties.enabledForDeployment] Property to specify
   * whether Azure Virtual Machines are permitted to retrieve certificates
   * stored as secrets from the key vault.
   * @member {boolean} [properties.enabledForDiskEncryption] Property to
   * specify whether Azure Disk Encryption is permitted to retrieve secrets
   * from the vault and unwrap keys.
   * @member {boolean} [properties.enabledForTemplateDeployment] Property to
   * specify whether Azure Resource Manager is permitted to retrieve secrets
   * from the key vault.
   * @member {boolean} [properties.enableSoftDelete] Property to specify
   * whether the 'soft delete' functionality is enabled for this key vault. It
   * does not accept false value.
   * @member {string} [properties.createMode] The vault's create mode to
   * indicate whether the vault need to be recovered or not. Possible values
   * include: 'recover', 'default'
   * @member {boolean} [properties.enablePurgeProtection] Property specifying
   * whether protection against purge is enabled for this vault. Setting this
   * property to true activates protection against purge for this vault and its
   * content - only the Key Vault service may initiate a hard, irrecoverable
   * deletion. The setting is effective only if soft delete is also enabled.
   * Enabling this functionality is irreversible - that is, the property does
   * not accept false as its value.
   * @member {object} [properties.networkAcls] A collection of rules governing
   * the accessibility of the vault from specific network locations.
   * @member {string} [properties.networkAcls.bypass] Tells what traffic can
   * bypass network rules. This can be 'AzureServices' or 'None'.  If not
   * specified the default is 'AzureServices'. Possible values include:
   * 'AzureServices', 'None'
   * @member {string} [properties.networkAcls.defaultAction] The default action
   * when no rule from ipRules and from virtualNetworkRules match. This is only
   * used after the bypass property has been evaluated. Possible values
   * include: 'Allow', 'Deny'
   * @member {array} [properties.networkAcls.ipRules] The list of IP address
   * rules.
   * @member {array} [properties.networkAcls.virtualNetworkRules] The list of
   * virtual network rules.
   */
  constructor() {
    super();
  }

  /**
   * Defines the metadata of VaultPatchParameters
   *
   * @returns {object} metadata of VaultPatchParameters
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'VaultPatchParameters',
      type: {
        name: 'Composite',
        className: 'VaultPatchParameters',
        modelProperties: {
          tags: {
            required: false,
            serializedName: 'tags',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          },
          properties: {
            required: false,
            serializedName: 'properties',
            type: {
              name: 'Composite',
              className: 'VaultPatchProperties'
            }
          }
        }
      }
    };
  }
}

module.exports = VaultPatchParameters;
