/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

/**
 * Properties of the vault
 *
 */
class VaultPatchProperties {
  /**
   * Create a VaultPatchProperties.
   * @member {uuid} [tenantId] The Azure Active Directory tenant ID that should
   * be used for authenticating requests to the key vault.
   * @member {object} [sku] SKU details
   * @member {string} [sku.name] SKU name to specify whether the key vault is a
   * standard vault or a premium vault. Possible values include: 'standard',
   * 'premium'
   * @member {array} [accessPolicies] An array of 0 to 16 identities that have
   * access to the key vault. All identities in the array must use the same
   * tenant ID as the key vault's tenant ID.
   * @member {boolean} [enabledForDeployment] Property to specify whether Azure
   * Virtual Machines are permitted to retrieve certificates stored as secrets
   * from the key vault.
   * @member {boolean} [enabledForDiskEncryption] Property to specify whether
   * Azure Disk Encryption is permitted to retrieve secrets from the vault and
   * unwrap keys.
   * @member {boolean} [enabledForTemplateDeployment] Property to specify
   * whether Azure Resource Manager is permitted to retrieve secrets from the
   * key vault.
   * @member {boolean} [enableSoftDelete] Property to specify whether the 'soft
   * delete' functionality is enabled for this key vault. It does not accept
   * false value.
   * @member {string} [createMode] The vault's create mode to indicate whether
   * the vault need to be recovered or not. Possible values include: 'recover',
   * 'default'
   * @member {boolean} [enablePurgeProtection] Property specifying whether
   * protection against purge is enabled for this vault. Setting this property
   * to true activates protection against purge for this vault and its content
   * - only the Key Vault service may initiate a hard, irrecoverable deletion.
   * The setting is effective only if soft delete is also enabled. Enabling
   * this functionality is irreversible - that is, the property does not accept
   * false as its value.
   * @member {object} [networkAcls] A collection of rules governing the
   * accessibility of the vault from specific network locations.
   * @member {string} [networkAcls.bypass] Tells what traffic can bypass
   * network rules. This can be 'AzureServices' or 'None'.  If not specified
   * the default is 'AzureServices'. Possible values include: 'AzureServices',
   * 'None'
   * @member {string} [networkAcls.defaultAction] The default action when no
   * rule from ipRules and from virtualNetworkRules match. This is only used
   * after the bypass property has been evaluated. Possible values include:
   * 'Allow', 'Deny'
   * @member {array} [networkAcls.ipRules] The list of IP address rules.
   * @member {array} [networkAcls.virtualNetworkRules] The list of virtual
   * network rules.
   */
  constructor() {
  }

  /**
   * Defines the metadata of VaultPatchProperties
   *
   * @returns {object} metadata of VaultPatchProperties
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'VaultPatchProperties',
      type: {
        name: 'Composite',
        className: 'VaultPatchProperties',
        modelProperties: {
          tenantId: {
            required: false,
            serializedName: 'tenantId',
            type: {
              name: 'String'
            }
          },
          sku: {
            required: false,
            serializedName: 'sku',
            type: {
              name: 'Composite',
              className: 'Sku'
            }
          },
          accessPolicies: {
            required: false,
            serializedName: 'accessPolicies',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'AccessPolicyEntryElementType',
                  type: {
                    name: 'Composite',
                    className: 'AccessPolicyEntry'
                  }
              }
            }
          },
          enabledForDeployment: {
            required: false,
            serializedName: 'enabledForDeployment',
            type: {
              name: 'Boolean'
            }
          },
          enabledForDiskEncryption: {
            required: false,
            serializedName: 'enabledForDiskEncryption',
            type: {
              name: 'Boolean'
            }
          },
          enabledForTemplateDeployment: {
            required: false,
            serializedName: 'enabledForTemplateDeployment',
            type: {
              name: 'Boolean'
            }
          },
          enableSoftDelete: {
            required: false,
            serializedName: 'enableSoftDelete',
            type: {
              name: 'Boolean'
            }
          },
          createMode: {
            required: false,
            serializedName: 'createMode',
            type: {
              name: 'Enum',
              allowedValues: [ 'recover', 'default' ]
            }
          },
          enablePurgeProtection: {
            required: false,
            serializedName: 'enablePurgeProtection',
            type: {
              name: 'Boolean'
            }
          },
          networkAcls: {
            required: false,
            serializedName: 'networkAcls',
            type: {
              name: 'Composite',
              className: 'NetworkRuleSet'
            }
          }
        }
      }
    };
  }
}

module.exports = VaultPatchProperties;
